%{
This is the script that calculates the D-Value from water evaporation
data.

In order to run the script an experiment must be specified. So write in
the command window "experiment = #" where # is a number between 1 and 2 and
corresponds to the experiment you want to look at.


%}
%% Clear old stuff and load data

clearvars -except experiment
D_values = [];

%O2
experiment = 1;

%Relevant for experiment 1 
%Which time is to be calculated
spot = 3;
    
    
aircell_shape = 'ellipsoid';

%Loads the data from the specified experiment
if experiment == 1
        
    load(strcat('VaporationData',int2str(experiment)))
    
    Water_vap = Water_vap{spot};
    
    viable_sample = spot*10-9:spot*10;
    daysToPlot = 1:length(Water_vap(1,:));
    DsToPlot = 1:length(Water_vap(1,:))-1;
    if spot == 1
        viable_sample = 1:10;
        Water_vap = Water_vap(viable_sample,daysToPlot);
        %viable_sample = viable_sample + 20;
    end
    nT = length(T);
    total_time = nT/60/24; %[days]

else
    load(strcat('VaporationData',int2str(experiment)))

end
if experiment ~=1
    Water_vap = Water_vap(viable_sample,daysToPlot);%*10^-6; %[m^3]
end
%Removes missing data and calculates some statistics about the eggs
c = c(viable_sample);
cap_vol = cap_vol(viable_sample);
Dia = Dia(viable_sample);
total_h = total_h(viable_sample);
a = Dia./2;

ShellThick = ShellThick(viable_sample);
time = linspace(0,total_time,nT); %[days]

[nEggs, nMeas] = size(Water_vap);
nPeriods = nMeas-1;


dayfrom = daysToPlot(1);
dayto = daysToPlot(end);
Dsfrom = DsToPlot(1);
DsTo = DsToPlot(end);

% Some general calculations and constants
R = 8.31446261815324;
act = 1;
tot_vap = Water_vap(:,1)-Water_vap(:,end); %[m^3]

%Calculate vapour pressure from RH and temperature using the Arden buck relation. 
%Since the temperature interval is so small this is fine

p_sat = p_Arden(T); %[mbar]
deltaP = p_sat.*(act - RH/100)*100; %[Pa]

% From partial pressure to concentration
deltaC = deltaP./((T+273.15)*R);

% Final volume is measured now 
% calculate volumes at the  different times of measuring
Area = areaWholeEgg(a,c,total_h);

cap_vol_time = zeros(size(Water_vap));
cap_vol_time(:,end) = cap_vol;
 for i = nMeas-1:-1:1
    cap_vol_time(:,i) = cap_vol_time(:,i+1)-(Water_vap(:,i)-Water_vap(:,i+1));
 end
%capvol = [capvol;mean(diff(cap_vol_time'))'];
 %% Figures out when the samples where taken out based on when the values of the RH changes dramatically

if experiment == 1 
        [pks, locs]= findpeaks(-T,'MinPeakHeight',-36.5,'MinPeakDistance',5);
        locs =  [locs([1,2,5]);nT];
        pks = [pks([1,2,5]); -T(end)];
        figure
        plot(time,-T)
        hold on
        plot(time(locs),pks,'or')
elseif experiment == 2 
        [pks, locs]= findpeaks(-T,'MinPeakHeight',-36.998,'MinPeakDistance',1000);
        figure
        hold on
        plot(time,-T)
        plot(time(locs),pks,'or')

end
timebetween = diff(time(locs(dayfrom:dayto)))*24*3600; %[s]
%% Uncomment this section if you want to see RH over time in the incubator 
% and when the programs calculates the incubator was opened


% figure
% plot(time,-T)
% hold on
% plot(time(locs),pks,'or')
%% Calculation of D-values with the followign host of assumptions in addition to the general assumptions
% Assumption 1: area and weight is constant between weight measurement points
% Assumption 2: The evaporation between weighting is dependant on the averages of the
% enviornment over the duration.
% Averaging between measurement points

moles_lost =  diff(cap_vol_time,1,2)*10^3./(18.015*10^-3); %[moles]

deltaCavg = zeros(size(moles_lost));
Tfactoravg = zeros(size(moles_lost));

for i = 1:nMeas-1
    if i == 1
    index_low = locs(i);
    else
        index_low = locs(i)+1;
    end
    index_high = locs(i+1);
    deltaCavg(:,i)= mean(deltaC(index_low:index_high));
    Tfactoravg(:,i) = mean(T(index_low:index_high).^3/2);

end
areaavg = Area;


D = moles_lost.*ShellThick./(deltaCavg.*areaavg.*timebetween);

%% Calculate D coarsegrained

moles_lost_coarse = -(Water_vap(:,end)-Water_vap(:,1))/(18.015*10^-3)*10^3;
   
D_coarse = moles_lost_coarse.*ShellThick./(mean(deltaCavg(1,:)).*Area.*sum(timebetween));


figure
plot(D_coarse)
hold on
plot(mean(D,2))
%% Relate all of this to oxygen diffusion
%Here the oxygen D-value is calculated based of the water vapour D-value
Water_D37 = 0.2267;
Water_D22 = 0.2055;
Oxygen_D37 = 0.2196;
Oxygen_D22 = 0.2011;

if mean(T) < 30
    
%if experiment == 6
    
    O2_D_med = D*Oxygen_D22/Water_D22;

    O2_D_coarse = D_coarse*Oxygen_D22/Water_D22;
else
    O2_D_med = D*Oxygen_D37/Water_D37;

    O2_D_coarse = D_coarse*Oxygen_D37/Water_D37;
    
end


%% Plot dvsdays

figure
plot(time(locs(DsToPlot)),O2_D_med','o')   
title(strcat('D-values over time. Experiment #',int2str(experiment)))
xlabel 'Time [days]'
ylabel 'D-value [m^2/s]'
ylim([0.4*10^-8 2*10^-8])


%% some plots to get an overview
% figure
% plot(Water_vap(:,1),tot_vap,'o')
% title 'Comparision between the total evaporation and total egg volume'
% ylabel 'Total evaporation [m^3]'
% xlabel ' Egg volume [m^3]' 
% figure
% plot(linspace(1,nMeas,nMeas),Water_vap')
% title 'Egg volumes over time'
% xlabel 'Time [days]'
% ylabel 'Egg volumes [m^3]'
% figure
% plot(low_samp_time(2:end),Vap_mass_perday)
% title 'Egg evaporation per day over time'
% ylabel 'Evaporation per day [m^3/day]'
% xlabel 'Time [days]'
% figure
% plot(ShellThick,tot_vap,'o')
% title 'Shell thickness vs total egg evaporation'
% ylabel 'Total evaporation [m^3]'
% xlabel 'Shell thickness [m]'

%% Plot the different grain sizes toghether

% plot(time_high(:,1),D_fine(2,:))
% hold on
% 
% plot(time_high(:,1),D_med_for_high(2,:))
% plot(time_high(:,1),ones(size(time_high(:,1)))*D_coarse(2))
% 
% title 'The 3 methods of averaging the D-value for 1 egg'
% xlabel 'time [days]'
% ylabel 'Diffusion constant [m^2/s]'
