classdef OxDataClass
    properties
        T {mustBeNumeric}
        RH {mustBeNumeric}
        t 
        pos {mustBeNumeric}
        ox {mustBeNumeric}
        data {mustBeNumeric}
        comments 
        Dia {mustBeNumeric}
        c {mustBeNumeric}
        total_h {mustBeNumeric}
        calibrationData {mustBeNumeric}
        hotplace 
        raw {mustBeNumeric}
    end
    methods 
        function obj = OxDataClass(filenameData,filenameEnv)
            %Returns data from the chosen excel sheets in the form of an OxDataClass

            %Import data from the specified excelsheet
            [numdata,~,rawdata] = xlsread(char(filenameData));
            [~,comments] = xlsread(char(filenameData),'Comments');
            [numenv, ~, rawenv] = xlsread(char(filenameEnv));

            %Assuming the datatime fits inside the enviornmenttime figure out what
            %matches what
            startTime = datetime(rawdata(2,1));
            endTime = datetime(rawdata(end,1));
            envTime = datetime(rawenv(3:end,2));

            envplace = find((startTime < envTime) & (envTime < endTime))+2;

            %extract the goodies from the imported datamatrices
            T = numenv(envplace,3);
            obj.RH = numenv(envplace,4);
            
            Sensor = char(comments(strncmpi(comments(:,3),'Sensor used',11),3));
            if isempty(Sensor)
                error('Which Sensor was used? Proper syntax is "Sensor used: #"')
            end
            
            sensor = str2double(Sensor(end-1:end));
            dataplace = 4+(sensor-1)*3;

            obj.t = numdata(2:end,2);
            obj.pos = numdata(2:end,3);
            obj.data = numdata(2:end,dataplace);
            

            %calibrate the sensor data
            dataTime = datetime(rawdata(2:end,1));
            
            hottimes = [comments(strncmpi(comments(:,3),'Heating on',10),1) comments(strncmpi(comments(:,3),'Heating off',10),1)];

            if length(hottimes) < 2
                error('Write out which times the heatimg was on. Proper syntax "Heating on" and "Heating off" in comments at the correct time')
            end
            
            obj.hotplace = find((hottimes(1) < dataTime) & (hottimes(2) > dataTime));
            
            
            %[comments(strncmpi(comments(:,3),'Calibration',11),1) comments(strncmpi(comments(:,3),'Calibration',10)+1,1)];
            
            
            calibtimes = datetime([comments(find(ismember(comments(:,3),'Calibration'))),comments(find(ismember(comments(:,3),'Calibration')) +1)]); %#ok
            if isempty(calibtimes)
                error('No calibration input found. Proper syntax is Calibration')
            end
            calibplace = find((calibtimes(1) < dataTime) & (calibtimes(2) > dataTime));

            %comments

            % Get info about the egg geometry 
            % First it looks for cells starting with keywords "width","Heigth" and
            % "total" Then grabs the last part of these cells as data.
            Diameter = char(comments(strncmpi(comments(:,3),'Diameter',5),3));
            tot_h = char(comments(strncmpi(comments(:,3),'Total',5),3));
            Height = char(comments(strncmpi(comments(:,3),'Height: ',6),3));
            
            if isempty(Diameter) 
                error('No diameter input found. Proper syntax is "Diameter: #####')
            elseif isempty(tot_h)
                error('No total height input found. Proper syntax is "Total #####')
            elseif isempty (Height)
                 error('No height input found. Proper syntax is "Height: ##')
            end

            obj.Dia = str2double(Diameter(end-5:end))*10^-3;

            obj.total_h = str2double(tot_h(end-5:end))*10^-3;

            obj.c = str2double(Height(end-2:end))*10^-3;
            
            obj.calibrationData = numdata(calibplace(1):calibplace(end),dataplace);

            obj.comments = comments;
            
            obj.raw = numdata(:,dataplace);
            [obj.ox,obj.T] = OxyCali(numdata(obj.hotplace,dataplace),T);



        end
    end
end
